<?php
namespace ElementorUniversal\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Modules\DynamicTags\Module as TagsModule;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Universal extends Widget_Base {

  /**
   * Retrieve the widget name.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'Universal_Video_Player';
  }

  /**
   * Retrieve the widget title.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return esc_html__( 'Universal - Video Player', 'elementor-universal' );
  }

  /**
   * Retrieve the widget icon.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-video-playlist';
  }

  /**
   * Retrieve the list of categories the widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * Note that currently Elementor supports only one category.
   * When multiple categories passed, Elementor uses the first one.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'lambert-widgets' ];
  }

  /**
   * Register the widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function register_controls() {
    //general controls (ex content)
    $this->start_controls_section(
      'general_content',
      [
        'label' => esc_html__( 'General Settings', 'elementor-universal' ),
      ]
    );
    $this->add_control(
			'skin',
			[
				'label' => __( 'Skin Name', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'whiteControllers'  => __( 'White Controllers', 'elementor-universal' ),
					'blackControllers' => __( 'Black Controllers', 'elementor-universal' ),
				],
        'default' => 'whiteControllers',
			]
		);
    $this->add_control(
      'xwidth',
      [
        'label' => esc_html__( 'Player Width', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '980',
      ]
    );
    $this->add_control(
      'xheight',
      [
        'label' => esc_html__( 'Player Height', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '399',
      ]
    );
    $this->add_control(
      'responsive',
      [
        'label' => esc_html__( 'Responsive', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );
    $this->add_control(
      'responsiveRelativeToBrowser',
      [
        'label' => esc_html__( 'Responsive Relative To Browser', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'false',
      ]
    );
    $this->add_control(
      'xcenter',
      [
        'label' => esc_html__( 'Center Player', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );
    $this->add_control(
      'getYouTubeData',
      [
        'label' => esc_html__( 'Automatically Obtain Thumbnail, Title &amp; Description From YouTube Server', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_block' => true,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'false',
      ]
    );
    $this->add_control(
			'loop',
			[
				'label' => esc_html__( 'Loop Playlist', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'advanceToNextVideo',
			[
				'label' => esc_html__( 'Advance To Next Video', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'autoPlayFirstVideo',
			[
				'label' => esc_html__( 'Auto Play First Video', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'false',
			]
		);
    $this->add_control(
			'autoPlayOnMobile',
			[
				'label' => esc_html__( 'Auto Play On Mobile', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'false',
			]
		);
    $this->add_control(
			'shuffle',
			[
				'label' => esc_html__( 'Shuffle', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'false',
			]
		);
    $this->add_control(
      'initialVolume',
      [
        'label' => esc_html__( 'Initial Volume Value', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1,
        'step' => 0.1,
        'default' => 1,
      ]
    );
    $this->add_control(
      'borderColor',
      [
        'label' => esc_html__( 'Player Border Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => '#4a4a4a',
      ]
    );
    $this->add_control(
      'controlsBgFullScreenColor',
      [
        'label' => esc_html__( 'Controls Bg FullScreen Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#000000',
      ]
    );
    $this->add_control(
      'bufferEmptyColor',
      [
        'label' => esc_html__( 'Empty Buffer Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#929292',
      ]
    );
    $this->add_control(
      'bufferFullColor',
      [
        'label' => esc_html__( 'Full Buffer Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#333333',
      ]
    );
    $this->add_control(
      'seekbarColor',
      [
        'label' => esc_html__( 'SeekBar Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#FFFFFF',
      ]
    );
    $this->add_control(
      'volumeOffColor',
      [
        'label' => esc_html__( 'Volume Off State Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#454545',
      ]
    );
    $this->add_control(
      'volumeOnColor',
      [
        'label' => esc_html__( 'Volume On State Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#FFFFFF',
      ]
    );
    $this->add_control(
      'timerColor',
      [
        'label' => esc_html__( 'Timer Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#FFFFFF',
      ]
    );
    $this->add_control(
      'topTitleColor',
      [
        'label' => esc_html__( 'Top Title Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#FFFFFF',
      ]
    );
    $this->add_control(
      'firstVideo',
      [
        'label' => esc_html__( 'First Video To Play', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '0',
      ]
    );
    $this->add_control(
      'suggestedQuality',
      [
        'label' => __( 'Suggested Quality', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
          'default'  => __( 'default', 'elementor-universal' ),
          'small' => __( 'small', 'elementor-universal' ),
          'medium' => __( 'medium', 'elementor-universal' ),
          'large' => __( 'large', 'elementor-universal' ),
          'hd720' => __( 'hd720', 'elementor-universal' ),
          'hd1080' => __( 'hd1080', 'elementor-universal' ),
          'highres' => __( 'highres', 'elementor-universal' ),
        ],
        'default' => 'default',
      ]
    );
    $this->add_control(
      'showLogo',
      [
        'label' => esc_html__( 'Show Logo', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'false',
      ]
    );
    $this->add_control(
    'logoImagePath',
    [
      'label' => esc_html__( 'Logo', 'elementor-universal' ),
      'type' => \Elementor\Controls_Manager::MEDIA,
      'default' => [
        'url' => \Elementor\Utils::get_placeholder_image_src(),
      ],
      'description' => esc_html__( 'you can upload your logo which will be displayed in the top-left corner on the video', 'elementor-universal' ),
    ]
    );
    $this->add_control(
      'logoLink',
      [
        'label' => esc_html__( 'Logo Link', 'elementor-universal' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => false,
        'default' => '',
      ]
    );
    $this->add_control(
      'logoTarget',
      [
        'label' => __( 'Logo Target', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
          '_blank'  => __( 'New Window', 'elementor-universal' ),
          '_self' => __( 'Same Window', 'elementor-universal' ),
        ],
        'default' => '_blank',
      ]
    );
    $this->add_control(
      'playButColorOff',
      [
        'label' => esc_html__( 'Play Button Color OFF State', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#de1a21',
      ]
    );
    $this->add_control(
      'playButColorOn',
      [
        'label' => esc_html__( 'Play Button Color ON State', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#de1a21',
      ]
    );
    $this->add_control(
			'showRewindBut',
			[
				'label' => esc_html__( 'Show Rewind Button', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'showPlayBut',
			[
				'label' => esc_html__( 'Show Play Button', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'showVolumeBut',
			[
				'label' => esc_html__( 'Show Volume Button', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'showShuffleBut',
			[
				'label' => esc_html__( 'Show Shuffle Button', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'showDownloadBut',
			[
				'label' => esc_html__( 'Show Download Button', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'showTwitterBut',
			[
				'label' => esc_html__( 'Show Twitter Button', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'showInfoBut',
			[
				'label' => esc_html__( 'Show Info Button', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'showFullscreenBut',
			[
				'label' => esc_html__( 'Show FullScreen Button', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'showNextPrevBut',
			[
				'label' => esc_html__( 'Show Next/Prev Buttons', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'showTopTitle',
			[
				'label' => esc_html__( 'Show Movie Top Title', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'showTimer',
			[
				'label' => esc_html__( 'Show Timer', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
      'showFacebookBut',
      [
        'label' => esc_html__( 'Show FaceBook Button', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );
    $this->add_control(
      'facebookAppID',
      [
        'label' => esc_html__( 'FaceBook AppID', 'elementor-universal' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => false,
        'default' => '',
      ]
    );
    $this->add_control(
      'googleTrakingOn',
      [
        'label' => esc_html__( 'Activate Google Analytics Traking', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'false',
      ]
    );
    $this->add_control(
      'googleTrakingCode',
      [
        'label' => esc_html__( 'Your Google Analytics Traking Code', 'elementor-universal' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => false,
        'default' => '',
        'description' => esc_html__( 'Example of code: UA-3245593-1', 'elementor-universal' ),
      ]
    );


    $this->end_controls_section();




    $this->start_controls_section(
      'playlist_settings_content',
      [
        'label' => esc_html__( 'Playlist Settings', 'elementor-universal' ),
      ]
    );
    $this->add_control(
      'showPlaylistOnInit',
      [
        'label' => esc_html__( 'Show Playlist On Init', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );
    $this->add_control(
      'showPlaylistBut',
      [
        'label' => esc_html__( 'Show Playlist Button', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );
    $this->add_control(
      'showPlaylist',
      [
        'label' => esc_html__( 'Show Playlist', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );
    $this->add_control(
      'playlistWidth',
      [
        'label' => esc_html__( 'Playlist Width', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '282',
      ]
    );
    $this->add_control(
      'bottomPlaylistWidth',
      [
        'label' => esc_html__( 'Show Playlist At The Bottom When the Resolution Is Less Than', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => true,
        'default' => '650',
      ]
    );
    $this->add_control(
      'playlistBgColor',
      [
        'label' => esc_html__( 'Playlist Background Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#4a4a4a',
      ]
    );
    $this->add_control(
      'origThumbImgW',
      [
        'label' => esc_html__( 'Thumb Width', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '69',
      ]
    );
    $this->add_control(
      'origThumbImgH',
      [
        'label' => esc_html__( 'Thumb Height', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '69',
      ]
    );
    $this->add_control(
			'playlistRecordShowImg',
			[
				'label' => esc_html__( 'Show Thumbs', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'playlistRecordShowTitle',
			[
				'label' => esc_html__( 'Show Title', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'playlistRecordShowDesc',
			[
				'label' => esc_html__( 'Show Description', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
      'playlistRecordHeight',
      [
        'label' => esc_html__( 'Playlist Record Height', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '89',
      ]
    );
    $this->add_control(
      'playlistRecordPadding',
      [
        'label' => esc_html__( 'Playlist Record Padding', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '10',
      ]
    );
    $this->add_control(
      'playlistTitleFontSize',
      [
        'label' => esc_html__( 'Title Font Size', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '15',
      ]
    );
    $this->add_control(
      'playlistTitleLineHeight',
      [
        'label' => esc_html__( 'Title Line Height', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '15',
      ]
    );
    $this->add_control(
      'playlistRecordTitleLimit',
      [
        'label' => esc_html__( 'Title Characters Limit', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '22',
      ]
    );
    $this->add_control(
      'playlistDescFontSize',
      [
        'label' => esc_html__( 'Description Font Size', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '12',
      ]
    );
    $this->add_control(
      'playlistDescLineHeight',
      [
        'label' => esc_html__( 'Description Line Height', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '15',
      ]
    );
    $this->add_control(
      'playlistRecordDescLimit',
      [
        'label' => esc_html__( 'Description Characters Limit', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '84',
      ]
    );
    $this->add_control(
      'playlistRecordBgOffColor',
      [
        'label' => esc_html__( 'Playlist Record Bkgd. Off Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'label_block' => false,
        'default' => '#eeeeee',
      ]
    );
    $this->add_control(
      'playlistRecordTitleOffColor',
      [
        'label' => esc_html__( 'Playlist Record Title OFF Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#333333',
      ]
    );
    $this->add_control(
      'playlistRecordDescOffColor',
      [
        'label' => esc_html__( 'Playlist Record Desc OFF Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#333333',
      ]
    );
    $this->add_control(
      'playlistRecordBgOnColor',
      [
        'label' => esc_html__( 'Playlist Record Bkgd. On Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'label_block' => false,
        'default' => '#de1a21',
      ]
    );
    $this->add_control(
      'playlistRecordTitleOnColor',
      [
        'label' => esc_html__( 'Playlist Record Title ON Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#FFFFFF',
      ]
    );
    $this->add_control(
      'playlistRecordDescOnColor',
      [
        'label' => esc_html__( 'Playlist Record Desc ON Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#FFFFFF',
      ]
    );
    $this->add_control(
      'numberOfThumbsPerScreen',
      [
        'label' => esc_html__( 'Number Of Items Per Screen', 'elementor-universal' ),
        'type' => Controls_Manager::NUMBER,
        'label_block' => false,
        'default' => '0',
      ]
    );
    $this->add_control(
      'playlistScrollerBgColorOFF',
      [
        'label' => esc_html__( 'Playlist Scroller Bg Color OFF', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#CCCCCC',
      ]
    );
    $this->add_control(
      'playlistScrollerBgColorON',
      [
        'label' => esc_html__( 'Playlist Scroller Bg Color ON', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#FFFFFF',
      ]
    );

    $this->end_controls_section();


    $this->start_controls_section(
      'categs_content',
      [
        'label' => esc_html__( 'Categories Settings', 'elementor-universal' ),
      ]
    );
    $this->add_control(
      'categoryRecordBgOffColor',
      [
        'label' => esc_html__( 'Category Record Background Off Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#000000',
      ]
    );
    $this->add_control(
      'categoryRecordBgOnColor',
      [
        'label' => esc_html__( 'Category Record Background On Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#252525',
      ]
    );
    $this->add_control(
      'categoryRecordBottomBorderOffColor',
      [
        'label' => esc_html__( 'Category Record Bottom Border Off Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => true,
        'default' => '#333333',
      ]
    );
    $this->add_control(
      'categoryRecordBottomBorderOnColor',
      [
        'label' => esc_html__( 'Category Record Bottom Border On Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => true,
        'default' => '#333333',
      ]
    );
    $this->add_control(
      'categoryRecordTextOffColor',
      [
        'label' => esc_html__( 'Category Record Text Off Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#4c4c4c',
      ]
    );
    $this->add_control(
      'categoryRecordTextOnColor',
      [
        'label' => esc_html__( 'Category Record Text On Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#de1a21',
      ]
    );
    $this->add_control(
      'showCategs',
      [
        'label' => esc_html__( 'Show Categories', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
        'label_off' => esc_html__( 'No', 'elementor-universal' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );
    $this->add_control(
			'firstCateg',
      [
				'label' => __( 'First Selected Category', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
        'description' => esc_html__( 'it must be one of the defined categories or you can leave it blank', 'elementor-universal' ),
			]
		);
    $this->add_control(
      'selectedCategBg',
      [
        'label' => esc_html__( 'Selected Categ Background Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'label_block' => false,
        'default' => 'transparent',
      ]
    );
    $this->add_control(
      'selectedCategOffColor',
      [
        'label' => esc_html__( 'Selected Categ Off Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'label_block' => false,
        'default' => '#FFFFFF',
      ]
    );
    $this->add_control(
      'selectedCategOnColor',
      [
        'label' => esc_html__( 'Selected Categ On Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'label_block' => false,
        'default' => '#de1a28',
      ]
    );
    $this->end_controls_section();


    $this->start_controls_section(
      'search_content',
      [
        'label' => esc_html__( 'Search Area', 'elementor-universal' ),
      ]
    );

    $this->add_control(
			'showSearch',
			[
				'label' => esc_html__( 'Show Search Area', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-universal' ),
				'label_off' => esc_html__( 'No', 'elementor-universal' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
      'searchAreaBg',
      [
        'label' => esc_html__( 'Search Area Background Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => 'transparent',
      ]
    );
    $this->add_control(
      'searchInputText',
      [
        'label' => esc_html__( 'Search Input Text', 'elementor-universal' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => false,
        'default' => 'search...',
      ]
    );
    $this->add_control(
      'searchInputBg',
      [
        'label' => esc_html__( 'Search Input Background Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#cccccc',
      ]
    );
    $this->add_control(
      'searchInputBorderColor',
      [
        'label' => esc_html__( 'Search Input Border Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => '#4a4a4a',
      ]
    );
    $this->add_control(
      'searchInputTextColor',
      [
        'label' => esc_html__( 'Search Input Text Color', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#333333',
      ]
    );

    $this->end_controls_section();





    /*playlist controls*/
    $this->start_controls_section(
      'playlist_content',
      [
        'label' => esc_html__( 'Playlist Items', 'elementor-universal' ),
      ]
    );


    $repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'title', [
				'label' => __( 'Title', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
			]
		);
    $repeater->add_control(
			'desc', [
				'label' => __( 'Description', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::TEXTAREA,
				'rows' => 10,
        'label_block' => true,
        'default' => '',
			]
		);
    $repeater->add_control(
			'category', [
				'label' => __( 'Category', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
        'description' => esc_html__( "If you'll define multiple categories for each song, you'll separate them by a semicolomn. Example: Category 1; Category 2", 'elementor-universal' ),
			]
		);
    $repeater->add_control(
		'imgplaylist',
		[
			'label' => esc_html__( 'Playlist Image', 'elementor-universal' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );
    $repeater->add_control(
      'youtube', [
        'label' => __( 'YouTube Video ID', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
        'description' => esc_html__( "If you want to play a YouTube video on this slide, you'll insert the YouTube video ID. A YouTube link is of this form https://www.youtube.com/watch?v=5WAkvu5Tnkw
The value of 'v' parameter is the ID you need.", 'elementor-universal' ),
      ]
    );
    $repeater->add_control(
      'vimeo', [
        'label' => __( 'Vimeo Video ID', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
        'description' => esc_html__( "If you want to play a Vimeo video on this slide, you'll insert the Vimeo video ID. A Vimeo link is of this form https://vimeo.com/21288282
The last number of the link is the ID", 'elementor-universal' ),
      ]
    );
    $repeater->add_control(
			'mp4',
			[
				'label' => esc_html__( 'Self Hosted/Third Party Hosted Video .MP4 file', 'elementor-universal' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
					'categories' => [
						TagsModule::MEDIA_CATEGORY,
					],
				],
				'media_type' => 'video'
			]
		);
    $repeater->add_control(
			'webm',
			[
				'label' => esc_html__( 'Self Hosted/Third Party Hosted Video .WEBM file (optional)', 'elementor-universal' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
					'categories' => [
						TagsModule::MEDIA_CATEGORY,
					],
				],
				'media_type' => 'video'
			]
		);
    $repeater->add_control(
      'startpoint', [
        'label' => __( 'Optional Start Time', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
        'description' => esc_html__( "it has to be of this form: HH:MM:SS", 'elementor-universal' ),
      ]
    );
    $repeater->add_control(
      'endpoint', [
        'label' => __( 'Optional End Time', 'elementor-universal' ),
        'type' => \Elementor\Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
        'description' => esc_html__( "it has to be of this form: HH:MM:SS", 'elementor-universal' ),
      ]
    );



    $this->add_control(
			'list',
			[
				'label' => __( 'Here you can add/edit/delete/clone the player playlist items', 'elementor-universal' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'title' => __( 'Video Title', 'elementor-universal' ),
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

    $this->end_controls_section();
  }

  /**
   * Render the widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function render() {
    $rand_id=rand(10,999999);
    $settings = $this->get_settings_for_display();

    $pathToDownloadFile_aux=plugin_dir_url(__FILE__).'universal_video_player/';
    ?>
    <script>
  		jQuery(function() {
                jQuery("#lbg_universal_<?php echo strip_tags($rand_id); ?>").universal_video_player({
                              skin:"<?php echo strip_tags($settings["skin"]); ?>",
                  						width:<?php echo strip_tags($settings["xwidth"]); ?>,
                  						height:<?php echo strip_tags($settings["xheight"]); ?>,
                  						responsive:<?php echo (($settings['responsive']==='true')?'true':'false'); ?>,
                  						responsiveRelativeToBrowser:<?php echo (($settings['responsiveRelativeToBrowser']==='true')?'true':'false'); ?>,
                  						centerPlayer:<?php echo (($settings['xcenter']==='true')?'true':'false'); ?>,
                  						shuffle:<?php echo (($settings['shuffle']==='true')?'true':'false'); ?>,
                  						firstVideo:<?php echo strip_tags($settings["firstVideo"]); ?>,
                  						initialVolume:<?php echo strip_tags($settings["initialVolume"]); ?>,
                  						loop:<?php echo (($settings['loop']==='true')?'true':'false'); ?>,
                  						showCategs:<?php echo (($settings['showCategs']==='true')?'true':'false'); ?>,
                  						showSearch:<?php echo (($settings['showSearch']==='true')?'true':'false'); ?>,
                  						showTopTitle:<?php echo (($settings['showTopTitle']==='true')?'true':'false'); ?>,
                  						showTimer:<?php echo (($settings['showTimer']==='true')?'true':'false'); ?>,
                  						showRewindBut:<?php echo (($settings['showRewindBut']==='true')?'true':'false'); ?>,
                  						showPlayBut:<?php echo (($settings['showPlayBut']==='true')?'true':'false'); ?>,
                  						showVolumeBut:<?php echo (($settings['showVolumeBut']==='true')?'true':'false'); ?>,
                  						showFacebookBut:<?php echo (($settings['showFacebookBut']==='true')?'true':'false'); ?>,
                  						facebookAppID:"<?php echo strip_tags($settings["facebookAppID"]); ?>",
                  						showTwitterBut:<?php echo (($settings['showTwitterBut']==='true')?'true':'false'); ?>,
                  						showInfoBut:<?php echo (($settings['showInfoBut']==='true')?'true':'false'); ?>,
                  						showDownloadBut:<?php echo (($settings['showDownloadBut']==='true')?'true':'false'); ?>,
                  						showPlaylistBut:<?php echo (($settings['showPlaylistBut']==='true')?'true':'false'); ?>,
                  						showFullscreenBut:<?php echo (($settings['showFullscreenBut']==='true')?'true':'false'); ?>,
                  						showShuffleBut:<?php echo (($settings['showShuffleBut']==='true')?'true':'false'); ?>,
                  						showNextPrevBut:<?php echo (($settings['showNextPrevBut']==='true')?'true':'false'); ?>,
                  						borderColor:"<?php echo strip_tags($settings["borderColor"]); ?>",
                  						playlistWidth:<?php echo strip_tags($settings["playlistWidth"]); ?>,
                  						pathToDownloadFile:"<?php echo strip_tags($pathToDownloadFile_aux); ?>",
                  						absUrl:"<?php echo strip_tags($pathToDownloadFile_aux); ?>",
                  						suggestedQuality:"<?php echo strip_tags($settings["suggestedQuality"]); ?>",
                  						controlsBgFullScreenColor:"<?php echo strip_tags($settings["controlsBgFullScreenColor"]); ?>",
                  						playlistScrollerBgColorOFF:"<?php echo strip_tags($settings["playlistScrollerBgColorOFF"]); ?>",
                  						playlistScrollerBgColorON:"<?php echo strip_tags($settings["playlistScrollerBgColorON"]); ?>",
                  						numberOfThumbsPerScreen:<?php echo strip_tags($settings["numberOfThumbsPerScreen"]); ?>,
                  						logoImagePath:"<?php echo strip_tags($settings["logoImagePath"]["url"]); ?>",
                  						logoLink:"<?php echo strip_tags($settings["logoLink"]); ?>",
                  						logoTarget:"<?php echo strip_tags($settings["logoTarget"]); ?>",
                  						showLogo:<?php echo (($settings['showLogo']==='true')?'true':'false'); ?>,
                  						autoPlayFirstVideo:<?php echo (($settings['autoPlayFirstVideo']==='true')?'true':'false'); ?>,
                  						autoPlayOnMobile:<?php echo (($settings['autoPlayOnMobile']==='true')?'true':'false'); ?>,
                  						advanceToNextVideo:<?php echo (($settings['advanceToNextVideo']==='true')?'true':'false'); ?>,
                  						playlistRecordShowImg:<?php echo (($settings['playlistRecordShowImg']==='true')?'true':'false'); ?>,
                  						playlistRecordShowTitle:<?php echo (($settings['playlistRecordShowTitle']==='true')?'true':'false'); ?>,
                  						playlistRecordShowDesc:<?php echo (($settings['playlistRecordShowDesc']==='true')?'true':'false'); ?>,
                  						playlistRecordHeight:<?php echo strip_tags($settings["playlistRecordHeight"]); ?>,
                  						playlistRecordPadding:<?php echo strip_tags($settings["playlistRecordPadding"]); ?>,
                  						playlistTitleFontSize:<?php echo strip_tags($settings["playlistTitleFontSize"]); ?>,
                  						playlistTitleLineHeight:<?php echo strip_tags($settings["playlistTitleLineHeight"]); ?>,
                  						playlistDescFontSize:<?php echo strip_tags($settings["playlistDescFontSize"]); ?>,
                  						playlistDescLineHeight:<?php echo strip_tags($settings["playlistDescLineHeight"]); ?>,
                  						playlistRecordBgOffColor:"<?php echo strip_tags($settings["playlistRecordBgOffColor"]); ?>",
                  						playlistRecordTitleOffColor:"<?php echo strip_tags($settings["playlistRecordTitleOffColor"]); ?>",
                  						playlistRecordDescOffColor:"<?php echo strip_tags($settings["playlistRecordDescOffColor"]); ?>",
                  						playlistRecordBgOnColor:"<?php echo strip_tags($settings["playlistRecordBgOnColor"]); ?>",
                  						playlistRecordTitleOnColor:"<?php echo strip_tags($settings["playlistRecordTitleOnColor"]); ?>",
                  						playlistRecordDescOnColor:"<?php echo strip_tags($settings["playlistRecordDescOnColor"]); ?>",
                  						playlistBgColor:"<?php echo strip_tags($settings["playlistBgColor"]); ?>",
                  						playlistRecordTitleLimit:<?php echo strip_tags($settings["playlistRecordTitleLimit"]); ?>,
                  						playlistRecordDescLimit:<?php echo strip_tags($settings["playlistRecordDescLimit"]); ?>,
                  						showPlaylistOnInit:<?php echo (($settings['showPlaylistOnInit']==='true')?'true':'false'); ?>,
                  						categoryRecordBgOffColor:"<?php echo strip_tags($settings["categoryRecordBgOffColor"]); ?>",
                  						categoryRecordBgOnColor:"<?php echo strip_tags($settings["categoryRecordBgOnColor"]); ?>",
                  						categoryRecordBottomBorderOffColor:"<?php echo strip_tags($settings["categoryRecordBottomBorderOffColor"]); ?>",
                  						categoryRecordBottomBorderOnColor:"<?php echo strip_tags($settings["categoryRecordBottomBorderOnColor"]); ?>",
                  						categoryRecordTextOffColor:"<?php echo strip_tags($settings["categoryRecordTextOffColor"]); ?>",
                  						categoryRecordTextOnColor:"<?php echo strip_tags($settings["categoryRecordTextOnColor"]); ?>",
                  						firstCateg:"<?php echo strip_tags($settings["firstCateg"]); ?>",
                  						selectedCategBg:"<?php echo strip_tags($settings["selectedCategBg"]); ?>",
                  						selectedCategOffColor:"<?php echo strip_tags($settings["selectedCategOffColor"]); ?>",
                  						selectedCategOnColor:"<?php echo strip_tags($settings["selectedCategOnColor"]); ?>",
                  						searchAreaBg:"<?php echo strip_tags($settings["searchAreaBg"]); ?>",
                  						searchInputText:"<?php echo strip_tags($settings["searchInputText"]); ?>",
                  						searchInputBg:"<?php echo strip_tags($settings["searchInputBg"]); ?>",
                  						searchInputBorderColor:"<?php echo strip_tags($settings["searchInputBorderColor"]); ?>",
                  						searchInputTextColor:"<?php echo strip_tags($settings["searchInputTextColor"]); ?>",
                  						topTitleColor:"<?php echo strip_tags($settings["topTitleColor"]); ?>",
                  						timerColor:"<?php echo strip_tags($settings["timerColor"]); ?>",
                  						bufferEmptyColor:"<?php echo strip_tags($settings["bufferEmptyColor"]); ?>",
                  						bufferFullColor:"<?php echo strip_tags($settings["bufferFullColor"]); ?>",
                  						seekbarColor:"<?php echo strip_tags($settings["seekbarColor"]); ?>",
                  						volumeOffColor:"<?php echo strip_tags($settings["volumeOffColor"]); ?>",
                  						volumeOnColor:"<?php echo strip_tags($settings["volumeOnColor"]); ?>",
                  						playButColorOff:"<?php echo strip_tags($settings["playButColorOff"]); ?>",
                  						playButColorOn:"<?php echo strip_tags($settings["playButColorOn"]); ?>",
                  						googleTrakingOn:<?php echo (($settings['googleTrakingOn']==='true')?'true':'false'); ?>,
                  						googleTrakingCode:"<?php echo strip_tags($settings["googleTrakingCode"]); ?>",
                  						getYouTubeData:<?php echo (($settings['getYouTubeData']==='true')?'true':'false'); ?>,
                  						pathToAjaxFiles:"<?php echo strip_tags($pathToDownloadFile_aux); ?>",
                  						origThumbImgW:<?php echo strip_tags($settings["origThumbImgW"]); ?>,
                  						origThumbImgH:<?php echo strip_tags($settings["origThumbImgH"]); ?>,
                  						bottomPlaylistWidth:<?php echo strip_tags($settings["bottomPlaylistWidth"]); ?>
                });
  		});
  	</script>
          <div id="lbg_universal_<?php echo strip_tags($rand_id); ?>" style="display:none;">
          				<ul class="universal_video_player_list">
                  <?php
                  if ( $settings['list'] ) {
                      foreach (  $settings['list'] as $item ) {
                        echo '<li data-bottom-thumb="'.strip_tags($item['imgplaylist']['url']).'" ';
                        echo 'data-title="'.strip_tags($item['title']).'" ';
                        echo 'data-desc="'.strip_tags($item['desc']).'" ';
                        echo 'data-youtube="'.strip_tags($item['youtube']).'" ';
                        echo 'data-vimeo="'.strip_tags($item['vimeo']).'" ';
                        echo 'data-selfhostedMP4="'.strip_tags($item['mp4']['url']).'" ';
                        echo 'data-selfhostedWEBM="'.strip_tags($item['webm']['url']).'" ';
                        echo 'data-startpoint="'.strip_tags($item['startpoint']).'" ';
                        echo 'data-endpoint="'.strip_tags($item['endpoint']).'" ';
                        echo 'data-category="'.(($item['category']!='')?strip_tags($item['category']):"ALL CATEGORIES").'" ';
                        echo '</li>';
                      }
                  }
                  ?>
                </ul>
        </div>
    <?php
  }

  /**
   * Render the widget output in the editor.
   *
   * Written as a Backbone JavaScript template and used to generate the live preview.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function content_template() {

  }
}
